==> nextcloud-app-news-1%3A25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ia.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Articulos non legite",
    "Download" : "Discargar",
    "Close" : "Clauder",
    "Web address" : "Adresse Web",
    "No folder" : "Nulle dossier",
    "Folder name" : "Nomine de dossier",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Feed exists already!" : "Syndication ja existe!",
    "New folder" : "Nove dossier",
    "Folder exists already!" : "Dossier ja existe!",
    "Credentials" : "Datos de authentication",
    "Subscribe" : "Subscribe",
    "Move" : "Mover",
    "Share" : "Compartir",
    "All articles" : "Tote articulos",
    "Starred" : "Favoritate",
    "Explore" : "Explorar",
    "Settings" : "Configurationes",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Disable mark read through scrolling" : "Disactivar le marcation como legite per rolamento",
    "Show all articles" : "Monstrar tote articulos",
    "Reverse ordering (oldest on top)" : "Ordination reverse (le plus ancian in le topo)",
    "Rename" : "Renominar",
    "Delete" : "Deler",
    "Toggle star article" : "Alternar stato de favorito del articulo",
    "by" : "per",
    "from" : "ex",
    "Play audio" : "Reproducer audio",
    "Download audio" : "Discargar audio",
    "Download video" : "Discargar video",
    "Open website" : "Aperir sito web",
    "Keep article unread" : "Mantener articulo como non legite",
    "Keyboard shortcut" : "Combination de claves",
    "Jump to next article" : "Saltar al articulo sequente",
    "Jump to previous article" : "Saltar al articulo previe",
    "right" : "dextere",
    "left" : "sinistre",
    "Star article and jump to next one" : "Favoritar articulo e saltar al sequente",
    "Open article in new tab" : "Aperir articulo in nove scheda",
    "Refresh" : "Refrescar",
    "No articles available" : "Nulle articulos disponibile",
    "No unread articles available" : "Nulle articulos non legite disponibile",
    "Star article" : "Favoritar articulo",
    "Unstar article" : "Disfavoritar articulo",
    "Description" : "Description",
    "Folder" : "Dossier",
    "Go back" : "Retornar",
    "New Folder" : "Nove dossier",
    "Create" : "Crear",
    "Update failed more than 50 times" : "Actualisation falleva plus que 50 vices",
    "Deleted feed" : "Syndication delite",
    "Undo delete feed" : "Disfacer deletion del syndication",
    "Menu" : "Menu",
    "Dismiss" : "Dimitter",
    "Collapse" : "Collaber",
    "Deleted folder" : "Dossier delite",
    "Undo delete folder" : "Disfacer deletion del dossier",
    "Compact view" : "Visualisation compacte",
    "Expand articles on key navigation" : "Expander articulos in navigation per claves",
    "Subscriptions (OPML)" : "Subscriptiones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Error durante importation: OPML contine ni syndicationes ni dossiers",
    "Unread/Starred Articles" : "Articulos Non Legite / Favorite",
    "Error when importing: file does not contain valid JSON" : "Error durante importation: file non contine un JSON valide",
    "Help" : "Adjuta",
    "Documentation" : "Documentation",
    "Report a bug" : "Reportar un defecto"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1%3A26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ia.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Articulos non legite",
    "Download" : "Discargar",
    "Close" : "Clauder",
    "Web address" : "Adresse Web",
    "No folder" : "Nulle dossier",
    "Folder name" : "Nomine de dossier",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Feed exists already!" : "Syndication ja existe!",
    "New folder" : "Nove dossier",
    "Folder exists already!" : "Dossier ja existe!",
    "Credentials" : "Datos de authentication",
    "Subscribe" : "Subscribe",
    "Move" : "Mover",
    "Share" : "Compartir",
    "All articles" : "Tote articulos",
    "Starred" : "Favoritate",
    "Explore" : "Explorar",
    "Settings" : "Configurationes",
    "Documentation" : "Documentation",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Disable mark read through scrolling" : "Disactivar le marcation como legite per rolamento",
    "Show all articles" : "Monstrar tote articulos",
    "Reverse ordering (oldest on top)" : "Ordination reverse (le plus ancian in le topo)",
    "Rename" : "Renominar",
    "Delete" : "Deler",
    "Previous" : "Previe",
    "Next" : "Proxime",
    "Toggle star article" : "Alternar stato de favorito del articulo",
    "by" : "per",
    "Play audio" : "Reproducer audio",
    "Download audio" : "Discargar audio",
    "Download video" : "Discargar video",
    "Open website" : "Aperir sito web",
    "Keep article unread" : "Mantener articulo como non legite",
    "Keyboard shortcut" : "Combination de claves",
    "Jump to next article" : "Saltar al articulo sequente",
    "Jump to previous article" : "Saltar al articulo previe",
    "right" : "dextere",
    "left" : "sinistre",
    "Star article and jump to next one" : "Favoritar articulo e saltar al sequente",
    "Open article in new tab" : "Aperir articulo in nove scheda",
    "Refresh" : "Refrescar"
},
"nplurals=2; plural=(n != 1);");
